//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

package com.cloud.network.bigswitch;

import com.cloud.host.HostVO;

public class ControlClusterData {
    private HostVO primary;
    private HostVO secondary;

    public HostVO getPrimary() {
        return primary;
    }

    public void setPrimary(HostVO primary) {
        this.primary = primary;
    }

    public HostVO getSecondary() {
        return secondary;
    }

    public void setSecondary(HostVO secondary) {
        this.secondary = secondary;
    }
}
